#!/bin/bash
#########################################

usage() {
    echo "$0 : <setup|remove>"
    echo "    This script will either setup custom logging in httpd.conf"
    echo "    or it will return the logging to the default"
    echo ""
    echo "    setup - will install the custom config"
    echo "    remove - will remove the custom config"
    exit 200
}

comment() {
    #########################################
    # set bread crumb
    TMPFILE=`mktemp`
    cat > $TMPFILE <<ERRORLOGCOMMENT
ins #comment before /files/etc/httpd/conf/httpd.conf/directive[ . = "ErrorLog" ]
set /files/etc/httpd/conf/httpd.conf/#comment[following-sibling::*[1][ . = "ErrorLog" ]] "$STAMP"
save
ERRORLOGCOMMENT

    augtool < $TMPFILE >/dev/null 2>&1

    rm -f $TMPFILE

    #########################################
    # set bread crumb
    TMPFILE=`mktemp`
    cat > $TMPFILE <<ACCESSLOGCOMMENT
ins #comment before /files/etc/httpd/conf/httpd.conf/IfModule[arg ="log_config_module"]/directive[ . = "CustomLog" ]
set /files/etc/httpd/conf/httpd.conf/IfModule[arg ="log_config_module"]/#comment[following-sibling::*[1][ . = "CustomLog" ]] "$STAMP"
save
ACCESSLOGCOMMENT

    augtool < $TMPFILE >/dev/null 2>&1

    rm -f $TMPFILE

}

# This installs the logging stanzas
setup() {
    TIMESTAMP=`date`
    STAMP="On $TIMESTAMP logging was set to syslog for clogger"

    # Comments are done in their own section so that
    # if they fail the real work is still done

    comment

    #########################################
    # use logger
    TMPFILE=`mktemp`
    cat > $TMPFILE <<ERRORLOG
set /files/etc/httpd/conf/httpd.conf/directive[ . = "ErrorLog" ]/arg '"| /usr/bin/logger  -thttpd -plocal6.err"'
save
ERRORLOG

    augtool < $TMPFILE >/dev/null 2>&1

    rm -f $TMPFILE


    #########################################
    # use logger
    TMPFILE=`mktemp`
    cat > $TMPFILE <<ACCESSLOG
set /files/etc/httpd/conf/httpd.conf/IfModule[arg ="log_config_module"]/directive[ . = "CustomLog" ]/arg[1] '"| /usr/bin/logger  -thttpd -plocal6.notice"'
save
ACCESSLOG
    augtool < $TMPFILE >/dev/null 2>&1

    rm -f $TMPFILE
}

# this returns things to the default
remove() {
    #########################################
    # use normal logs
    TIMESTAMP=`date`
    STAMP="On $TIMESTAMP logging was set to local log files only"

    comment

    TMPFILE=`mktemp`
    cat > $TMPFILE <<ACCESSLOG
set /files/etc/httpd/conf/httpd.conf/*[ . = "ErrorLog" ]/arg 'logs/error_log'
save
ACCESSLOG
    augtool < $TMPFILE >/dev/null 2>&1

    rm -f $TMPFILE

    #########################################
    # use normal logs
    TMPFILE=`mktemp`
    cat > $TMPFILE <<ACCESSLOG
set /files/etc/httpd/conf/httpd.conf/IfModule[arg ="log_config_module"]/directive[ . = "CustomLog" ]/arg[1] 'logs/access_log'
save
ACCESSLOG
    augtool < $TMPFILE >/dev/null 2>&1

    rm -f $TMPFILE
}

#######################################################

if [[ "$1" == 'setup' ]]; then
    setup
elif [[ "$1" == 'remove' ]]; then
    remove
else
    usage
fi
